# -*- coding:utf-8 -*-
from __future__ import absolute_import, unicode_literals, print_function

class DBManage:
    def __init__(self, filename):
        pass

    def select(self, keyword):
        pass

    def update(self, keyword):
        return False

    def insert(self, keyword, data):
        return False

    def delete(self, keyword):
        return False
